Learn R Programming

MatrixModels (version 0.2-1)

Model-class: Mother Class "Model" all S4 Models

Description

Class "Model" is meant to be the mother class of all (S4) model classes. As some useful methods are already defined for "Model" objects, derived classes inherit those for free.

Arguments

Objects from the Class

A virtual Class: No objects may be created from it.

See Also

the glpModel class in package MatrixModels which extends this class.

Examples

Run this code
showClass("Model")

Run the code above in your browser using DataLab