Learn R Programming

MatrixModels (version 0.2-1)

glpModel-class: Class "glpModel" of General Linear Prediction Models

Description

The class "glpModel" conceptually contains a very large class of General Linear Prediction Models.

Its resp slot (of class "respModule") may model linear, non-linear, generalized linear and non-linear generalized response models.

Arguments

Objects from the Class

Objects can be created by calls of the form new("glpModel", ...), but typically rather are returned by our modeling functions, e.g., the (experimental, hence currently hidden) glm4().

Extends

Class "Model", directly.

See Also

glm4() returns fitted glpModel objects.

The constituents of this class are respModule and predModule, both of which have several sub classes.

Examples

Run this code
showClass("glpModel")

## Use   example(glm4)  or see  help(glm4) for many more examples.

Run the code above in your browser using DataLab