Learn R Programming

MatrixModels (version 0.2-1)

updateMu: Update 'mu', the Fitted Mean Response

Description

Updates the mean vector $\mu$ given the linear predictor $\gamma$. Evaluate the residuals and the weighted sum of squared residuals.

Usage

updateMu(respM, gamma, ...)

Arguments

respM
a response module, see the respModule class.
gamma
the value of the linear predictor before adding the offset
...
potentially further arguments used in methods; not used currently.

Value

  • updated respM

Details

Note that the offset is added to the linear predictor before calculating mu.

The sqrtXwt matrix can be updated but the sqrtrwt should not be in that the weighted sum of squared residuals should be calculated relative to fixed weights. Reweighting is done in a separate call.

See Also

The respModule class (and specific subclasses); glm4.

Examples

Run this code
## TODO

Run the code above in your browser using DataLab