Model-class: Mother Class "Model" all S4 Models
Description
Class "Model" is meant to be the mother class of all (S4) model
classes.
As some useful methods are already defined for "Model" objects,
derived classes inherit those for free.Objects from the Class
A virtual Class: No objects may be created from it.See Also
the glpModel class in package
MatrixModels which extends this class.