glpModel-class: Class "glpModel" of General Linear Prediction Models
Description
The class "glpModel" conceptually contains a very large class
of General Linear Prediction Models.
Its resp slot (of class "respModule") may
model linear, non-linear, generalized linear and non-linear
generalized response models.
Arguments
Objects from the Class
Objects can be created by calls of the form new("glpModel", ...),
but typically rather are returned by our modeling functions, e.g., the
(experimental, hence currently hidden) glm4().